package com.jiuqi.util;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.nio.ByteBuffer;
import java.nio.channels.Channels;
import java.nio.channels.FileChannel;
import java.nio.channels.WritableByteChannel;

public class FileClassLoader extends ClassLoader {
   private String baseDir;

   public FileClassLoader(String baseDir) {
      this.baseDir = baseDir;
   }

   public FileClassLoader(ClassLoader parent, String baseDir) {
      super(parent);
      this.baseDir = baseDir;
   }

   protected Class findClass(String name) throws ClassNotFoundException {
      byte[] bytes = this.loadClassBytes(name);
      Class theClass = null;

      try {
         theClass = this.defineClass(name, bytes, 0, bytes.length);
      } catch (Exception var5) {
         Exception e = var5;
         e.printStackTrace();
      }

      if (theClass == null) {
         throw new ClassFormatError();
      } else {
         return theClass;
      }
   }

   private byte[] loadClassBytes(String className) throws ClassNotFoundException {
      try {
         String classFile = this.getClassFile(className);
         FileInputStream fis = new FileInputStream(classFile);
         FileChannel fileC = fis.getChannel();
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         WritableByteChannel outC = Channels.newChannel(baos);
         ByteBuffer buffer = ByteBuffer.allocateDirect(1024);

         while(true) {
            int i = fileC.read(buffer);
            if (i == 0 || i == -1) {
               fis.close();
               return baos.toByteArray();
            }

            buffer.flip();
            outC.write(buffer);
            buffer.clear();
         }
      } catch (IOException var9) {
         IOException fnfe = var9;
         throw new ClassNotFoundException(className, fnfe);
      }
   }

   private String getClassFile(String name) {
      StringBuffer sb = new StringBuffer(this.baseDir);
      name = name.replace('.', File.separatorChar) + ".class";
      sb.append(File.separator + name);
      return sb.toString();
   }

   protected URL findResource(String name) {
      try {
         URL url = super.findResource(name);
         if (url != null) {
            return url;
         } else {
            url = new URL("file:///" + this.converName(name));
            return url;
         }
      } catch (MalformedURLException var3) {
         return null;
      }
   }

   private String converName(String name) {
      StringBuffer sb = new StringBuffer(this.baseDir);
      name = name.replace('.', File.separatorChar);
      sb.append(File.separator + name);
      return sb.toString();
   }
}
